#!/usr/bin/python
# -*- coding:utf-8 -*-
import sys
import os
picdir = os.path.join(os.path.dirname(os.path.dirname(os.path.realpath(__file__))), 'pic')
libdir = os.path.join(os.path.dirname(os.path.dirname(os.path.realpath(__file__))), 'lib')
if os.path.exists(libdir):
    sys.path.append(libdir)

import logging
from waveshare_epd import epd2in13b
import time
from PIL import Image,ImageDraw,ImageFont
import traceback
from paho.mqtt import client as mqtt_client
import paho.mqtt.client as paho

logging.basicConfig(level=logging.DEBUG)

Connected = False   #global variable for the state of the connection

broker = "192.168.99.224"
port = 1883
topic_wHouseConsumption = "openWB/global/WHouseConsumption"
topic_pvProduction = "openWB/pv/W"
topic_energyImportExport = "openWB/evu/W"
topic_houseBatterySoC = "openWB/housebattery/%Soc"
topic_houseBatteryLoadUnload = "openWB/housebattery/W"

username = "mqtt-user"
pw = "phio6yiR9ohs1veeghu4WaeGhaiRi8he4EiWasheev4faeku8tohdiuthah7zahP"
client_id = "solarmonitor"

try:
    epd = epd2in13b.EPD()
    logging.info("init and Clear")
    epd.init()
    epd.Clear()
    time.sleep(1)

except IOError as e:
    logging.info(e)
    
except KeyboardInterrupt:    
    logging.info("ctrl + c:")
    epd2in13b.epdconfig.module_exit()
    exit()

def on_connect(client, userdata, flags, rc):
    if rc == 0:
        print("Connected to MQTT Broker!")

        global Connected                #Use global variable
        Connected = True                #Signal connection 
    else:
        print("Failed to connect, return code %d\n", rc)

def on_message(client, userdata, msg):
    global value_pvProduction
    global value_wHouseConsumption
    global value_energyImportExport
    global value_houseBatterySoC
    global value_houseBatteryLoadUnload

    if msg.topic == "openWB/pv/W":
        value_pvProduction = ""+msg.payload.decode()
    elif msg.topic == "openWB/global/WHouseConsumption":
        value_wHouseConsumption = ""+msg.payload.decode()
    elif msg.topic == "openWB/evu/W":
        value_energyImportExport = ""+msg.payload.decode()
    elif msg.topic == "openWB/housebattery/%Soc":
        value_houseBatterySoC = ""+msg.payload.decode()
    elif msg.topic == "openWB/housebattery/W":  
        value_houseBatteryLoadUnload = ""+msg.payload.decode()  

client = mqtt_client.Client(client_id, protocol=paho.MQTTv31)
client.username_pw_set(username, password=pw)
client.on_connect = on_connect

value_pvProduction = ""
value_wHouseConsumption = ""
value_energyImportExport = ""
value_houseBatterySoC = ""
value_houseBatteryLoadUnload = ""

client.on_message = on_message

client.connect(broker, port=port)

client.loop_start()        #start the loop
  
while Connected != True:    #Wait for connection
    time.sleep(1)

client.subscribe(topic_wHouseConsumption)
client.subscribe(topic_pvProduction)
client.subscribe(topic_energyImportExport)
client.subscribe(topic_houseBatterySoC)
client.subscribe(topic_houseBatteryLoadUnload)


try:
    while True:
        # Drawing on the image
        logging.info("Drawing")
        font10 = ImageFont.truetype(os.path.join(picdir, 'Font.ttc'), 12)
        
        # Drawing on the Horizontal image
        logging.info("1.Drawing on the Horizontal image...") 
        HBlackimage = Image.new('1', (epd.height, epd.width), 255)  # 298*126
        HRedimage = Image.new('1', (epd.height, epd.width), 255)  # 298*126  ryimage: red or yellow image  
        drawblack = ImageDraw.Draw(HBlackimage)
        drawred = ImageDraw.Draw(HRedimage)
        drawblack.text((5, 0), 'PV Produktion', font = font10, fill = 0)
        drawblack.text((5, 15), 'Hausverbrauch', font = font10, fill = 0)
        drawblack.text((5, 30), 'Strom Import/Export', font = font10, fill = 0)
        drawblack.text((5, 45), 'Batterie %', font = font10, fill = 0)
        drawblack.text((5, 60), 'Batterie Laden/Entladen', font = font10, fill = 0)
        #epd.display(epd.getbuffer(HBlackimage), epd.getbuffer(HRedimage))
        #epd.display(epd.getbuffer(HBlackimage))

        print("-----")
        logging.info("test")
        logging.info("PvP: "+value_pvProduction)
        logging.info("Hou: "+value_wHouseConsumption)
        logging.info("I/E: "+value_energyImportExport)
        logging.info("SoC: "+value_houseBatterySoC)
        logging.info("Bio: "+value_houseBatteryLoadUnload)
        #drawblack.rectangle((150, 0, 220, 50), fill = 255)
        drawblack.text((150, 0), value_pvProduction, font = font10, fill = 0)
        #drawblack.rectangle((150, 15, 220, 50), fill = 255)
        drawblack.text((150, 15), value_wHouseConsumption, font = font10, fill = 0)
        #drawblack.rectangle((150, 30, 220, 50), fill = 255)
        drawblack.text((150, 30), value_energyImportExport, font = font10, fill = 0)
        #drawblack.rectangle((150, 45, 220, 50), fill = 255)
        drawblack.text((150, 45), value_houseBatterySoC, font = font10, fill = 0)
        #drawblack.rectangle((150, 60, 220, 50), fill = 255)
        drawblack.text((150, 60), value_houseBatteryLoadUnload, font = font10, fill = 0)

        epd.display(epd.getbuffer(HBlackimage), epd.getbuffer(HRedimage))

        time.sleep(10)
  
except KeyboardInterrupt:
    print("exiting")
    client.disconnect()
    client.loop_stop()
